/*

Copyright (C) 2000, 2001, 2002 Christian Kreibich <christian@whoop.org>.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies of the Software and its documentation and acknowledgment shall be
given in the documentation and software packages that this Software was
used.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*/
#ifndef __nd_prefs_h
#define __nd_prefs_h

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <string.h>
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include <sys/types.h>

#define ND_DOM_NETDUDE   "Netdude"

typedef enum
{
  ND_PREFS_INT = 1,
  ND_PREFS_FLT = 2,
  ND_PREFS_STR = 3,
  ND_PREFS_UNK = 4
} ND_PrefsType;


typedef struct nd_prefs_entry
{
  const char             *key;
  ND_PrefsType            type;

  int                     int_val;
  float                   flt_val;
  const char             *str_val;

} ND_PrefsEntry;

typedef void (*ND_PrefsApplyCallback) (GtkWidget *container,
				       ND_PrefsEntry *entries,
				       int num_entries);

/* You can use this to make statically initialized tables
 * more readable, see nd_prefs.c.
 */
#define ND_UNUSED 0

/* Initializes preferences handling, reads
   config file etc. TRUE on success, FALSE
   otherwise.
*/
void           nd_prefs_init(void);
void           nd_prefs_load(void);

const char    *nd_prefs_get_netdude_dir(void);
const char    *nd_prefs_get_config_file(void);
const char    *nd_prefs_get_plugin_dir_global(void);
const char    *nd_prefs_get_plugin_dir_user(void);
const char    *nd_prefs_get_proto_dir_global(void);
const char    *nd_prefs_get_proto_dir_user(void);


void           nd_prefs_add_domain(const char *domain,
				   GtkWidget *container,
				   GtkWidget *gui,
				   ND_PrefsEntry *entries,
				   int num_entries,
				   ND_PrefsApplyCallback apply_cb);

/* Saves current preferences to disk.
   TRUE on success, FALSE otherwise.
 */
int            nd_prefs_save(void);

/* Saves to disk general settings that are not
   directly influenced by the user (such as
   load/save directories).
*/
void           nd_prefs_save_general(void);

/* Get/Set preferences. */
void           nd_prefs_set_str_item(const char *domain, const char *key, const char *data);
void           nd_prefs_set_flt_item(const char *domain, const char *key, float data);
void           nd_prefs_set_int_item(const char *domain, const char *key, int data);

void           nd_prefs_del_item(const char *domain, const char *key);

gboolean       nd_prefs_get_str_item(const char *domain, const char *key, char **result);
gboolean       nd_prefs_get_flt_item(const char *domain, const char *key, float *result);
gboolean       nd_prefs_get_int_item(const char *domain, const char *key, int   *result);

/* GUI callbacks. */
void           nd_prefs_dialog_show(void);
void           nd_prefs_dialog_ok(void);
void           nd_prefs_dialog_apply(void);
void           nd_prefs_dialog_cancel(void);

void           nd_prefs_fontsel_show(void);

/* Sync dialog content to current config settings: */
void           nd_prefs_dialog_sync(void);

void           nd_prefs_select_tcpdump(void);

#endif
